@@ -1,9 +1,10 @@
 from django.contrib import messages
 from django.shortcuts import get_object_or_404
 from django.utils.translation import gettext_lazy as _
+from django.views import View
+
 from process.conf import get_conf
 from .generic_views import (
-    View,
     ProcessSecurity,
     ProcessGenericCreateView,
     ProcessGenericListView,
